@@ -288,9 +288,9 @@ class OpenStackConfig(object):
     def _fix_backwards_project(self, cloud):
         # Do the lists backwards so that project_name is the ultimate winner
         mappings = {
-            'project_name': ('tenant_id', 'tenant-id',
-                             'project_id', 'project-id',
-                             'tenant_name', 'tenant-name',
+            'project_id': ('tenant_id', 'tenant-id',
+                           'project_id', 'project-id'),
+            'project_name': ('tenant_name', 'tenant-name',
                              'project_name', 'project-name'),
         }
         for target_key, possible_values in mappings.items():
@@ -383,8 +383,12 @@ class OpenStackConfig(object):
 
     def _validate_auth(self, config):
         # May throw a keystoneclient.exceptions.NoMatchingPlugin
-        plugin_options = ksc_auth.get_plugin_class(
-            config['auth_type']).get_options()
+        if config['auth_type'] == 'admin_endpoint':
+            auth_plugin = ksc_auth.token_endpoint.Token
+        else:
+            auth_plugin = ksc_auth.get_plugin_class(config['auth_type'])
+
+        plugin_options = auth_plugin.get_options()
 
         for p_opt in plugin_options:
             # if it's in config.auth, win, kill it from config dict
