@@ -38,6 +38,9 @@ VENDOR_CONF = {
     }
 }
 USER_CONF = {
+    'client': {
+        'prefer_ipv6': True,
+    },
     'clouds': {
         '_test-cloud_': {
             'profile': '_test_cloud_in_our_cloud',
@@ -64,6 +67,25 @@ USER_CONF = {
             },
             'region_name': 'test-region',
         },
+        '_test_cloud_regions': {
+            'auth': {
+                'username': 'testuser',
+                'password': 'testpass',
+                'project-id': 'testproject',
+            },
+            'regions': [
+                'region1',
+                'region2',
+            ],
+        },
+        '_test_cloud_hyphenated': {
+            'auth': {
+                'username': 'testuser',
+                'password': 'testpass',
+                'project-id': '12345',
+            },
+            'region_name': 'test-region',
+        }
     },
     'cache': {'max_age': 1},
 }
@@ -110,4 +132,8 @@ class TestCase(base.BaseTestCase):
         self.assertIsNone(cc.cloud)
         self.assertIn('username', cc.auth)
         self.assertEqual('testuser', cc.auth['username'])
-        self.assertEqual('testproject', cc.auth['project_name'])
+        self.assertTrue('project_name' in cc.auth or 'project_id' in cc.auth)
+        if 'project_name' in cc.auth:
+            self.assertEqual('testproject', cc.auth['project_name'])
+        elif 'project_id' in cc.auth:
+            self.assertEqual('testproject', cc.auth['project_id'])
