@@ -32,7 +32,11 @@ class TestConfig(base.TestCase):
         c = config.OpenStackConfig(config_files=[self.cloud_yaml],
                                    vendor_files=[self.vendor_yaml])
         clouds = c.get_all_clouds()
-        user_clouds = [cloud for cloud in base.USER_CONF['clouds'].keys()]
+        # We add one by hand because the regions cloud is going to exist
+        # twice since it has two regions in it
+        user_clouds = [
+            cloud for cloud in base.USER_CONF['clouds'].keys()
+        ] + ['_test_cloud_regions']
         configured_clouds = [cloud.name for cloud in clouds]
         self.assertItemsEqual(user_clouds, configured_clouds)
 
@@ -85,7 +89,13 @@ class TestConfig(base.TestCase):
         c = config.OpenStackConfig(config_files=[self.cloud_yaml],
                                    vendor_files=[self.vendor_yaml])
         cc = c.get_one_cloud('_test-cloud-int-project_')
-        self.assertEqual('12345', cc.auth['project_name'])
+        self.assertEqual('12345', cc.auth['project_id'])
+
+    def test_get_one_cloud_with_hyphenated_project_id(self):
+        c = config.OpenStackConfig(config_files=[self.cloud_yaml],
+                                   vendor_files=[self.vendor_yaml])
+        cc = c.get_one_cloud('_test_cloud_hyphenated')
+        self.assertEqual('12345', cc.auth['project_id'])
 
     def test_no_environ(self):
         c = config.OpenStackConfig(config_files=[self.cloud_yaml],
@@ -101,6 +111,18 @@ class TestConfig(base.TestCase):
                 self.useFixture(fixtures.EnvironmentVariable(k))
         c.get_one_cloud(cloud='defaults')
 
+    def test_prefer_ipv6_true(self):
+        c = config.OpenStackConfig(config_files=[self.cloud_yaml],
+                                   vendor_files=[self.vendor_yaml])
+        cc = c.get_one_cloud(cloud='_test-cloud_')
+        self.assertTrue(cc.prefer_ipv6)
+
+    def test_prefer_ipv6_false(self):
+        c = config.OpenStackConfig(config_files=[self.no_yaml],
+                                   vendor_files=[self.no_yaml])
+        cc = c.get_one_cloud(cloud='defaults')
+        self.assertFalse(cc.prefer_ipv6)
+
     def test_get_one_cloud_auth_merge(self):
         c = config.OpenStackConfig(config_files=[self.cloud_yaml])
         cc = c.get_one_cloud(cloud='_test-cloud_', auth={'username': 'user'})
@@ -112,7 +134,9 @@ class TestConfig(base.TestCase):
         self.assertEqual(
             ['_test-cloud-int-project_',
              '_test-cloud_',
+             '_test_cloud_hyphenated',
              '_test_cloud_no_vendor',
+             '_test_cloud_regions',
              ],
             sorted(c.get_cloud_names()))
         c = config.OpenStackConfig(config_files=[self.no_yaml],
@@ -197,6 +221,25 @@ class TestConfigArgparse(base.TestCase):
         self.assertEqual(cc.region_name, 'test-region')
         self.assertIsNone(cc.snack_type)
 
+    def test_get_one_cloud_no_argparse_regions(self):
+        c = config.OpenStackConfig(config_files=[self.cloud_yaml],
+                                   vendor_files=[self.vendor_yaml])
+
+        cc = c.get_one_cloud(cloud='_test_cloud_regions', argparse=None)
+        self._assert_cloud_details(cc)
+        self.assertEqual(cc.region_name, 'region1')
+        self.assertIsNone(cc.snack_type)
+
+    def test_get_one_cloud_no_argparse_region2(self):
+        c = config.OpenStackConfig(config_files=[self.cloud_yaml],
+                                   vendor_files=[self.vendor_yaml])
+
+        cc = c.get_one_cloud(
+            cloud='_test_cloud_regions', region_name='region2', argparse=None)
+        self._assert_cloud_details(cc)
+        self.assertEqual(cc.region_name, 'region2')
+        self.assertIsNone(cc.snack_type)
+
     def test_fix_env_args(self):
         c = config.OpenStackConfig(config_files=[self.cloud_yaml],
                                    vendor_files=[self.vendor_yaml])
@@ -209,9 +252,47 @@ class TestConfigArgparse(base.TestCase):
 
 class TestConfigDefault(base.TestCase):
 
+    def setUp(self):
+        super(TestConfigDefault, self).setUp()
+
+        # Reset defaults after each test so that other tests are
+        # not affected by any changes.
+        self.addCleanup(self._reset_defaults)
+
+    def _reset_defaults(self):
+        defaults._defaults = None
+
     def test_set_no_default(self):
         c = config.OpenStackConfig(config_files=[self.cloud_yaml],
                                    vendor_files=[self.vendor_yaml])
         cc = c.get_one_cloud(cloud='_test-cloud_', argparse=None)
         self._assert_cloud_details(cc)
-        self.assertEqual(cc.auth_type, 'password')
+        self.assertEqual('password', cc.auth_type)
+
+    def test_set_default_before_init(self):
+        config.set_default('auth_type', 'token')
+        c = config.OpenStackConfig(config_files=[self.cloud_yaml],
+                                   vendor_files=[self.vendor_yaml])
+        cc = c.get_one_cloud(cloud='_test-cloud_', argparse=None)
+        self.assertEqual('token', cc.auth_type)
+
+
+class TestBackwardsCompatibility(base.TestCase):
+
+    def test_set_no_default(self):
+        c = config.OpenStackConfig(config_files=[self.cloud_yaml],
+                                   vendor_files=[self.vendor_yaml])
+        cloud = {
+            'identity_endpoint_type': 'admin',
+            'compute_endpoint_type': 'private',
+            'endpoint_type': 'public',
+            'auth_type': 'v3password',
+        }
+        result = c._fix_backwards_interface(cloud)
+        expected = {
+            'identity_interface': 'admin',
+            'compute_interface': 'private',
+            'interface': 'public',
+            'auth_type': 'v3password',
+        }
+        self.assertEqual(expected, result)
